==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/uk_ua/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.edit.text_add'] = 'Додати';
$lang['AdminDepartments.edit.text_delete'] = 'Видалити';
$lang['AdminDepartments.edit.heading_default'] = 'За замовчуванням';
$lang['AdminDepartments.edit.heading_value'] = 'Значення';
$lang['AdminDepartments.edit.heading_name'] = 'Ім\'я';
$lang['AdminDepartments.edit.heading_options'] = 'Параметри';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Автоматичне видалення';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Зашифровано.';
$lang['AdminDepartments.edit.heading_client_add'] = 'Клієнт може додати';
$lang['AdminDepartments.edit.heading_step'] = 'Крок';
$lang['AdminDepartments.edit.heading_max'] = 'Максе.';
$lang['AdminDepartments.edit.heading_min'] = 'Min';
$lang['AdminDepartments.edit.heading_type'] = 'Тип';
$lang['AdminDepartments.edit.heading_visibility'] = 'Видимість';
$lang['AdminDepartments.edit.heading_description'] = 'Опис';
$lang['AdminDepartments.edit.heading_label'] = 'Етикетка';
$lang['AdminDepartments.edit.no_results'] = 'У цьому відділі немає користувацьких полів.';
$lang['AdminDepartments.edit.confirm_field_remove'] = 'Ви впевнені, що хочете видалити це кастомне поле? Всі дані, пов\'язані з цим полем, будуть видалені. Якщо ви хочете приховати це поле і зберегти дані, змініть його видимість на "Тільки для персоналу".';
$lang['AdminDepartments.edit.field_add_field'] = 'Додати поле';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Відділ редагування';
$lang['AdminDepartments.edit.field_status'] = 'Статус';
$lang['AdminDepartments.edit.field_response_id'] = 'Відповідь про автоматичне закриття тікета';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Надсилати нагадування про квитки з пріоритетом';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Надсилати нагадування до квитків зі статусом';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Автоматично надсилати нагадування про квитки';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Автоматичне видалення квитків';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Автоматично закривати квитки';
$lang['AdminDepartments.edit.field_port'] = 'Порт';
$lang['AdminDepartments.edit.field_pass'] = 'Перепустка.';
$lang['AdminDepartments.edit.field_user'] = 'Користувач';
$lang['AdminDepartments.edit.field_host'] = 'Ведучий';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Позначте повідомлення як';
$lang['AdminDepartments.edit.field_box_name'] = 'Назва поля';
$lang['AdminDepartments.edit.field_security'] = 'Безпека';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Максимальний розмір вкладення';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Підтримувані типи вкладень';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Додавайте підтримувані вкладення до повідомлень про тікети';
$lang['AdminDepartments.edit.field_default_priority'] = 'Пріоритет за замовчуванням';
$lang['AdminDepartments.edit.field_piping_config'] = 'Конфігурація трубопроводів';
$lang['AdminDepartments.edit.field_method'] = 'Робота з електронною поштою';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Автоматично змінювати статус тікета після відповіді адміністратора';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Надсилайте листи з автопідтвердженням для нових квитків';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Замініть адресу від, встановлену в шаблонах листів, на адресу, встановлену для цього відділу';
$lang['AdminDepartments.edit.field_email'] = 'Електронна пошта';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Вимагати людську верифікацію для неавторизованих користувачів';
$lang['AdminDepartments.edit.field_clients_only'] = 'Дозволити тільки клієнтам відкривати тікети або відповідати на них';
$lang['AdminDepartments.edit.field_description'] = 'Опис';
$lang['AdminDepartments.edit.field_name'] = 'Ім\'я';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Користувацькі поля';
$lang['AdminDepartments.edit.tab_general'] = 'Генерал';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Відділ редагування';
$lang['AdminDepartments.add.text_add'] = 'Додати';
$lang['AdminDepartments.add.text_delete'] = 'Видалити';
$lang['AdminDepartments.add.heading_default'] = 'За замовчуванням';
$lang['AdminDepartments.add.heading_value'] = 'Значення';
$lang['AdminDepartments.add.heading_name'] = 'Ім\'я';
$lang['AdminDepartments.add.heading_options'] = 'Параметри';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Автоматичне видалення';
$lang['AdminDepartments.add.heading_encrypted'] = 'Зашифровано.';
$lang['AdminDepartments.add.heading_client_add'] = 'Клієнт може додати';
$lang['AdminDepartments.add.heading_step'] = 'Крок';
$lang['AdminDepartments.add.heading_max'] = 'Максе.';
$lang['AdminDepartments.add.heading_min'] = 'Min';
$lang['AdminDepartments.add.heading_type'] = 'Тип';
$lang['AdminDepartments.add.heading_visibility'] = 'Видимість';
$lang['AdminDepartments.add.heading_description'] = 'Опис';
$lang['AdminDepartments.add.heading_label'] = 'Етикетка';
$lang['AdminDepartments.add.field_add_field'] = 'Додати поле';
$lang['AdminDepartments.add.field_addsubmit'] = 'Додати відділ';
$lang['AdminDepartments.add.field_status'] = 'Статус';
$lang['AdminDepartments.add.field_response_id'] = 'Відповідь про автоматичне закриття тікета';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Надсилати нагадування про квитки з пріоритетом';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Надсилати нагадування до квитків зі статусом';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Автоматично надсилати нагадування про квитки';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Автоматичне видалення квитків';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Автоматично закривати квитки';
$lang['AdminDepartments.add.field_port'] = 'Порт';
$lang['AdminDepartments.add.field_pass'] = 'Перепустка.';
$lang['AdminDepartments.add.field_user'] = 'Користувач';
$lang['AdminDepartments.add.field_host'] = 'Ведучий';
$lang['AdminDepartments.add.field_mark_messages'] = 'Позначте повідомлення як';
$lang['AdminDepartments.add.field_box_name'] = 'Назва поля';
$lang['AdminDepartments.add.field_security'] = 'Безпека';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Максимальний розмір вкладення';
$lang['AdminDepartments.add.field_attachment_types'] = 'Підтримувані типи вкладень';
$lang['AdminDepartments.add.field_include_attachments'] = 'Додавайте підтримувані вкладення до повідомлень про тікети';
$lang['AdminDepartments.add.field_default_priority'] = 'Пріоритет за замовчуванням';
$lang['AdminDepartments.add.field_piping_config'] = 'Конфігурація трубопроводів';
$lang['AdminDepartments.add.field_method'] = 'Робота з електронною поштою';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Автоматично змінювати статус тікета після відповіді адміністратора';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Надсилайте листи з автопідтвердженням для нових квитків';
$lang['AdminDepartments.add.field_override_from_email'] = 'Замініть адресу від, встановлену в шаблонах листів, на адресу, встановлену для цього відділу';
$lang['AdminDepartments.add.field_email'] = 'Електронна пошта';
$lang['AdminDepartments.add.field_require_captcha'] = 'Вимагати людську верифікацію для неавторизованих користувачів';
$lang['AdminDepartments.add.field_clients_only'] = 'Дозволити тільки клієнтам відкривати тікети або відповідати на них';
$lang['AdminDepartments.add.field_description'] = 'Опис';
$lang['AdminDepartments.add.field_name'] = 'Ім\'я';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Користувацькі поля';
$lang['AdminDepartments.add.tab_general'] = 'Генерал';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Додати відділ';
$lang['AdminDepartments.!text.remove_response'] = 'Видалити';
$lang['AdminDepartments.!text.no_selected_response'] = 'Не вибрано відповідь на автоматичне закриття.';
$lang['AdminDepartments.!text.add_response'] = 'Налаштувати автоматичне закриття заздалегідь визначеної відповіді';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Якщо квиток закрито, дані з полів будуть автоматично видалені. Дані більше не будуть видимими для персоналу.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Чи може клієнт відправити поле, якщо значення false, то клієнт зможе лише прочитати поле.';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Максимальний розмір вкладеного файлу в МБ.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Список підтримуваних розширень через кому (наприклад, zip, jpg, png).';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Поштові сервери мають обмеження на розмір і типи вкладених файлів. Щоб зменшити ризик того, що лист буде відхилено, будь ласка, вказуйте обмеження на тип і розмір вкладень. Щоб бути впевненим, що клієнт знає про вкладення, які не були включені, використовуйте тег {ticket.reply_has_attachments} в повідомленнях про тікети.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Змінює статус на %1$s, коли співробітник відповідає.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'Зняття прапорця вказує на те, що нові тікети, створені для цього відділу (електронною поштою або клієнтом), не будуть надсилати повідомлення про відповідь клієнту або співробітнику через електронну пошту Ticket Received або Staff Ticket Updated, відповідно.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'Для всіх квитків зі статусом, відмінним від %1$s, буде надіслано нагадування іншій стороні, якщо протягом обраного часу не буде отримано жодної відповіді.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Всі квитки зі статусом %1$s будуть автоматично видалені після того, як вони залишаться в цьому статусі протягом певного часу.';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Всі тікети зі статусом, відмінним від %1$s, остання відповідь на які надійшла від співробітника, будуть автоматично закриті, якщо протягом обраного часу на них не буде надано жодної відповіді.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Встановіть шлях до конвеєра, як показано на малюнку, але переконайтеся, що ви використовуєте правильний шлях до PHP на вашому сервері. Переконайтеся, що файл pipe.php є виконуваним. Вам також може знадобитися відредагувати pipe.php, щоб включити хеш-бан в рядку 1, який буде виглядати приблизно так: #!/usr/bin/php';
$lang['AdminDepartments.assigned_staff.no_results'] = 'За цим відділом не закріплено жодного працівника.';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Персонал';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Призначений персонал';
$lang['AdminDepartments.index.no_results'] = 'Відділів немає.';
$lang['AdminDepartments.index.confirm_delete'] = 'Відділи, за якими закріплені квитки, не можуть бути видалені, поки всі квитки не будуть перепризначені іншому відділу. Ви впевнені, що хочете видалити цей відділ?';
$lang['AdminDepartments.index.option_delete'] = 'Видалити';
$lang['AdminDepartments.index.option_edit'] = 'Редагувати';
$lang['AdminDepartments.index.heading_options'] = 'Параметри';
$lang['AdminDepartments.index.heading_default_priority'] = 'Пріоритет за замовчуванням';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Призначений персонал';
$lang['AdminDepartments.index.heading_email'] = 'Електронна пошта';
$lang['AdminDepartments.index.heading_description'] = 'Опис';
$lang['AdminDepartments.index.heading_name'] = 'Ім\'я';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Відділи';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Додати відділ';
$lang['AdminDepartments.edit.page_title'] = 'Менеджер підтримки > Відділи > Редагувати відділ';
$lang['AdminDepartments.add.page_title'] = 'Менеджер підтримки > Відділи > Додати відділ';
$lang['AdminDepartments.index.page_title'] = 'Менеджер підтримки > Відділи';
$lang['AdminDepartments.!success.department_deleted'] = 'Відділ %1$s успішно видалено.';
$lang['AdminDepartments.!success.department_updated'] = 'Відділ %1$s було успішно оновлено.';
$lang['AdminDepartments.!success.department_created'] = 'Відділ %1$s був успішно створений.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/uk_ua/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.edit.text_add'] = 'Додати';
$lang['AdminDepartments.edit.text_delete'] = 'Видалити';
$lang['AdminDepartments.edit.heading_default'] = 'За замовчуванням';
$lang['AdminDepartments.edit.heading_value'] = 'Значення';
$lang['AdminDepartments.edit.heading_name'] = 'Ім\'я';
$lang['AdminDepartments.edit.heading_options'] = 'Параметри';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Автоматичне видалення';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Зашифровано.';
$lang['AdminDepartments.edit.heading_client_add'] = 'Клієнт може додати';
$lang['AdminDepartments.edit.heading_step'] = 'Крок';
$lang['AdminDepartments.edit.heading_max'] = 'Максе.';
$lang['AdminDepartments.edit.heading_min'] = 'Min';
$lang['AdminDepartments.edit.heading_type'] = 'Тип';
$lang['AdminDepartments.edit.heading_visibility'] = 'Видимість';
$lang['AdminDepartments.edit.heading_description'] = 'Опис';
$lang['AdminDepartments.edit.heading_label'] = 'Етикетка';
$lang['AdminDepartments.edit.no_results'] = 'У цьому відділі немає користувацьких полів.';
$lang['AdminDepartments.edit.confirm_field_remove'] = 'Ви впевнені, що хочете видалити це кастомне поле? Всі дані, пов\'язані з цим полем, будуть видалені. Якщо ви хочете приховати це поле і зберегти дані, змініть його видимість на "Тільки для персоналу".';
$lang['AdminDepartments.edit.field_add_field'] = 'Додати поле';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Відділ редагування';
$lang['AdminDepartments.edit.field_status'] = 'Статус';
$lang['AdminDepartments.edit.field_response_id'] = 'Відповідь про автоматичне закриття тікета';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Надсилати нагадування про квитки з пріоритетом';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Надсилати нагадування до квитків зі статусом';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Автоматично надсилати нагадування про квитки';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Автоматичне видалення квитків';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Автоматично закривати квитки';
$lang['AdminDepartments.edit.field_port'] = 'Порт';
$lang['AdminDepartments.edit.field_pass'] = 'Перепустка.';
$lang['AdminDepartments.edit.field_user'] = 'Користувач';
$lang['AdminDepartments.edit.field_host'] = 'Ведучий';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Позначте повідомлення як';
$lang['AdminDepartments.edit.field_box_name'] = 'Назва поля';
$lang['AdminDepartments.edit.field_security'] = 'Безпека';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Максимальний розмір вкладення';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Підтримувані типи вкладень';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Додавайте підтримувані вкладення до повідомлень про тікети';
$lang['AdminDepartments.edit.field_default_priority'] = 'Пріоритет за замовчуванням';
$lang['AdminDepartments.edit.field_piping_config'] = 'Конфігурація трубопроводів';
$lang['AdminDepartments.edit.field_method'] = 'Робота з електронною поштою';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Автоматично змінювати статус тікета після відповіді адміністратора';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Надсилайте листи з автопідтвердженням для нових квитків';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Замініть адресу від, встановлену в шаблонах листів, на адресу, встановлену для цього відділу';
$lang['AdminDepartments.edit.field_email'] = 'Електронна пошта';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Вимагати людську верифікацію для неавторизованих користувачів';
$lang['AdminDepartments.edit.field_clients_only'] = 'Дозволити тільки клієнтам відкривати тікети або відповідати на них';
$lang['AdminDepartments.edit.field_description'] = 'Опис';
$lang['AdminDepartments.edit.field_name'] = 'Ім\'я';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Користувацькі поля';
$lang['AdminDepartments.edit.tab_general'] = 'Генерал';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Відділ редагування';
$lang['AdminDepartments.add.text_add'] = 'Додати';
$lang['AdminDepartments.add.text_delete'] = 'Видалити';
$lang['AdminDepartments.add.heading_default'] = 'За замовчуванням';
$lang['AdminDepartments.add.heading_value'] = 'Значення';
$lang['AdminDepartments.add.heading_name'] = 'Ім\'я';
$lang['AdminDepartments.add.heading_options'] = 'Параметри';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Автоматичне видалення';
$lang['AdminDepartments.add.heading_encrypted'] = 'Зашифровано.';
$lang['AdminDepartments.add.heading_client_add'] = 'Клієнт може додати';
$lang['AdminDepartments.add.heading_step'] = 'Крок';
$lang['AdminDepartments.add.heading_max'] = 'Максе.';
$lang['AdminDepartments.add.heading_min'] = 'Min';
$lang['AdminDepartments.add.heading_type'] = 'Тип';
$lang['AdminDepartments.add.heading_visibility'] = 'Видимість';
$lang['AdminDepartments.add.heading_description'] = 'Опис';
$lang['AdminDepartments.add.heading_label'] = 'Етикетка';
$lang['AdminDepartments.add.field_add_field'] = 'Додати поле';
$lang['AdminDepartments.add.field_addsubmit'] = 'Додати відділ';
$lang['AdminDepartments.add.field_status'] = 'Статус';
$lang['AdminDepartments.add.field_response_id'] = 'Відповідь про автоматичне закриття тікета';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Надсилати нагадування про квитки з пріоритетом';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Надсилати нагадування до квитків зі статусом';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Автоматично надсилати нагадування про квитки';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Автоматичне видалення квитків';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Автоматично закривати квитки';
$lang['AdminDepartments.add.field_port'] = 'Порт';
$lang['AdminDepartments.add.field_pass'] = 'Перепустка.';
$lang['AdminDepartments.add.field_user'] = 'Користувач';
$lang['AdminDepartments.add.field_host'] = 'Ведучий';
$lang['AdminDepartments.add.field_mark_messages'] = 'Позначте повідомлення як';
$lang['AdminDepartments.add.field_box_name'] = 'Назва поля';
$lang['AdminDepartments.add.field_security'] = 'Безпека';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Максимальний розмір вкладення';
$lang['AdminDepartments.add.field_attachment_types'] = 'Підтримувані типи вкладень';
$lang['AdminDepartments.add.field_include_attachments'] = 'Додавайте підтримувані вкладення до повідомлень про тікети';
$lang['AdminDepartments.add.field_default_priority'] = 'Пріоритет за замовчуванням';
$lang['AdminDepartments.add.field_piping_config'] = 'Конфігурація трубопроводів';
$lang['AdminDepartments.add.field_method'] = 'Робота з електронною поштою';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Автоматично змінювати статус тікета після відповіді адміністратора';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Надсилайте листи з автопідтвердженням для нових квитків';
$lang['AdminDepartments.add.field_override_from_email'] = 'Замініть адресу від, встановлену в шаблонах листів, на адресу, встановлену для цього відділу';
$lang['AdminDepartments.add.field_email'] = 'Електронна пошта';
$lang['AdminDepartments.add.field_require_captcha'] = 'Вимагати людську верифікацію для неавторизованих користувачів';
$lang['AdminDepartments.add.field_clients_only'] = 'Дозволити тільки клієнтам відкривати тікети або відповідати на них';
$lang['AdminDepartments.add.field_description'] = 'Опис';
$lang['AdminDepartments.add.field_name'] = 'Ім\'я';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Користувацькі поля';
$lang['AdminDepartments.add.tab_general'] = 'Генерал';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Додати відділ';
$lang['AdminDepartments.!text.remove_response'] = 'Видалити';
$lang['AdminDepartments.!text.no_selected_response'] = 'Не вибрано відповідь на автоматичне закриття.';
$lang['AdminDepartments.!text.add_response'] = 'Налаштувати автоматичне закриття заздалегідь визначеної відповіді';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Якщо квиток закрито, дані з полів будуть автоматично видалені. Дані більше не будуть видимими для персоналу.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Чи може клієнт відправити поле, якщо значення false, то клієнт зможе лише прочитати поле.';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Максимальний розмір вкладеного файлу в МБ.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Список підтримуваних розширень через кому (наприклад, zip, jpg, png).';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Поштові сервери мають обмеження на розмір і типи вкладених файлів. Щоб зменшити ризик того, що лист буде відхилено, будь ласка, вказуйте обмеження на тип і розмір вкладень. Щоб бути впевненим, що клієнт знає про вкладення, які не були включені, використовуйте тег {ticket.reply_has_attachments} в повідомленнях про тікети.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Змінює статус на %1$s, коли співробітник відповідає.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'Зняття прапорця вказує на те, що нові тікети, створені для цього відділу (електронною поштою або клієнтом), не будуть надсилати повідомлення про відповідь клієнту або співробітнику через електронну пошту Ticket Received або Staff Ticket Updated, відповідно.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'Для всіх квитків зі статусом, відмінним від %1$s, буде надіслано нагадування іншій стороні, якщо протягом обраного часу не буде отримано жодної відповіді.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Всі квитки зі статусом %1$s будуть автоматично видалені після того, як вони залишаться в цьому статусі протягом певного часу.';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Всі тікети зі статусом, відмінним від %1$s, остання відповідь на які надійшла від співробітника, будуть автоматично закриті, якщо протягом обраного часу на них не буде надано жодної відповіді.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Встановіть шлях до конвеєра, як показано на малюнку, але переконайтеся, що ви використовуєте правильний шлях до PHP на вашому сервері. Переконайтеся, що файл pipe.php є виконуваним. Вам також може знадобитися відредагувати pipe.php, щоб включити хеш-бан в рядку 1, який буде виглядати приблизно так: #!/usr/bin/php';
$lang['AdminDepartments.assigned_staff.no_results'] = 'За цим відділом не закріплено жодного працівника.';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Персонал';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Призначений персонал';
$lang['AdminDepartments.index.no_results'] = 'Відділів немає.';
$lang['AdminDepartments.index.confirm_delete'] = 'Відділи, за якими закріплені квитки, не можуть бути видалені, поки всі квитки не будуть перепризначені іншому відділу. Ви впевнені, що хочете видалити цей відділ?';
$lang['AdminDepartments.index.option_delete'] = 'Видалити';
$lang['AdminDepartments.index.option_edit'] = 'Редагувати';
$lang['AdminDepartments.index.heading_options'] = 'Параметри';
$lang['AdminDepartments.index.heading_default_priority'] = 'Пріоритет за замовчуванням';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Призначений персонал';
$lang['AdminDepartments.index.heading_email'] = 'Електронна пошта';
$lang['AdminDepartments.index.heading_description'] = 'Опис';
$lang['AdminDepartments.index.heading_name'] = 'Ім\'я';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Відділи';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Додати відділ';
$lang['AdminDepartments.edit.page_title'] = 'Менеджер підтримки > Відділи > Редагувати відділ';
$lang['AdminDepartments.add.page_title'] = 'Менеджер підтримки > Відділи > Додати відділ';
$lang['AdminDepartments.index.page_title'] = 'Менеджер підтримки > Відділи';
$lang['AdminDepartments.!success.department_deleted'] = 'Відділ %1$s успішно видалено.';
$lang['AdminDepartments.!success.department_updated'] = 'Відділ %1$s було успішно оновлено.';
$lang['AdminDepartments.!success.department_created'] = 'Відділ %1$s був успішно створений.';
$lang['AdminDepartments.edit.field_priorities'] = 'Доступні пріоритети';
$lang['AdminDepartments.add.field_priorities'] = 'Доступні пріоритети';
$lang['AdminDepartments.edit.field_force_import'] = 'Імпорт сили';
$lang['AdminDepartments.add.field_force_import'] = 'Імпорт сили';
$lang['AdminDepartments.!success.department_imported'] = 'Відділ %1$s було успішно імпортовано.';
